function PredationMatrix = f_CalcPredationMatrix(TotalConsumptionVector, DietMatrix)
% Calculate the predation matrix (a.k.a.: bottom-up matrix, inverse transposition, predator matrix)
% a_ij = (b_ij * C_i) / sigma(b_ji * C_i) for all i	(Eq. QQQ)
%
% 	a(i,j)						= PredationMatrix(i,j)
% 	b(j,i)						= DietMatrix(j,i)
% 	C(i)							= TotalConsumptionVector(i)
% 	sigma(b(j,i) * C(i)) for all i	= TotalPredation(j)
% 	j							= prey index
% 	i							= predator index
% revision date: 4-29-2010

% STEP 1: measure matrix and vector sizes
[rows_diet, clms_diet] = size(DietMatrix);
rows_cons = length(TotalConsumptionVector);
if rows_diet ~= rows_cons
    error('consumption vector and diet matrix are of mis-matched size')
end

% STEP 2: calculate total predation on each prey, j, = sigma(b_ji * C_i) for all i. This is the denominator in Eq. QQQ. 
Predation(1:rows_diet, 1:clms_diet) = 0; % initialize Predation matrix
for prey_loop = 1:rows_diet % (1 to j)
	Predation(prey_loop, :) = DietMatrix(prey_loop, :) .* TotalConsumptionVector;
end
TotalPredation = sum(Predation, 2); % total predation on each prey, j, (vertical vector)

% STEP 3: calculate the bottom-up, production matrix
for prey_loop = 1:rows_diet % (prey, j: down rows)
	for predator_loop = 1:clms_diet % (predators, i: across columns)
        PredationMatrix(predator_loop, prey_loop) = (DietMatrix(prey_loop, predator_loop) * TotalConsumptionVector(predator_loop)) / TotalPredation(prey_loop);
    end
end

% STEP 4: correct divide by 0 errors for groups with no predation, e.g. mammals, (PredationMatrix = 0)
PredationMatrix(isnan(PredationMatrix)) = 0;
 
 % end m-file*******************************************************