function [SINGLE_ECO] = f_ECOfunction_01112015(ModelDefinitions, CurrentModel)
% generate a single ECOTRAN model for 1 "type" EwE model or 1 MonteCarlo EwE model
% by Jim Ruzicka
% calls:
%       f_RedistributeCannibalism           remove cannibalism terms on diagonal of matrix EwE_diet
%       f_CalcPredationMatrix               for each producer, p, and consumer, c: ((b_pc * Q_c) / M2_p)) = the fraction of total predation on each producer, p, going to each consumer, c
%       f_AggregateResults_ECOTRANS         (QQQ optional; usually turned off; not present in this code version)
% takes:
%       ModelDefinitions
%       CurrentModel
%
% returns:
%   budget items (these include clms for nutrients, fisheries, detritus)
%           SINGLE_ECO.BigMatrix                                main ECOTRAN matrix (aka "production matrix", "energy budget"); (no BA & EM rows)
%           SINGLE_ECO.BioenergeticBudget
%           SINGLE_ECO.BioenergeticBudget_ProductionDetail
%           SINGLE_ECO.BioenergeticBudget_OtherMortDetail
%           SINGLE_ECO.BioenergeticBudget_FecesDetail
%           SINGLE_ECO.ProductionBudget
%           SINGLE_ECO.ProductionBudget_OtherMortDetail
%   group types & names (these include rows for nutrients, fisheries, detritus, and BA & EM; or 1 row for each detritus type in case of _detritus names)
%           SINGLE_ECO.GroupType
%           SINGLE_ECO.AggLabel
%           SINGLE_ECO.GroupType_detritus
%           SINGLE_ECO.AggLabel_detritus
%   EwE parameters (these include rows for fisheries and detritus; no nutrients, no BA & EM)
%           SINGLE_ECO.EwE_Biomass
%           SINGLE_ECO.EwE_PB
%           SINGLE_ECO.EwE_QB
%           SINGLE_ECO.EwE_PQ
%           SINGLE_ECO.EwE_AE
%           SINGLE_ECO.EwE_BA
%           SINGLE_ECO.EwE_EM



%   EwE fisheries (1 clm for each gear group; these DO NOT include rows for nutrients, fisheries, nor BA & EM)
%           SINGLE_ECO.EwE_Landings
%           SINGLE_ECO.EwE_Discards
%           SINGLE_ECO.EwE_TotalFishery
%   EcotrophicEfficiency terms (these include rows for fisheries and detritus; no nutrients, no BA & EM)
%           SINGLE_ECO.EcotrophicEfficiency_predation
%           SINGLE_ECO.EcotrophicEfficiency_BA
%           SINGLE_ECO.EcotrophicEfficiency_EM
%           SINGLE_ECO.EcotrophicEfficiency
%           SINGLE_ECO.TransferEfficiency
% revision date: 1-11-2015





% *************************************************************************
% STEP 1: unpack variables sent to function--------------------------------
% step 1a: parameters from the 1 defining EwE model (these apply to all MonteCarlo models)
DetritusFate_feces        = ModelDefinitions.DetritusFate_feces;
DetritusFate_senescence   = ModelDefinitions.DetritusFate_senescence; % row 1 = pelagic detritus; row 2 = benthic detritus; (2 horizontal vectors)
PelagicBacterialReduction = ModelDefinitions.PelagicBacterialReduction; % fraction of pelagic detritus returned to DIN (scaler)
BenthicBacterialReduction = ModelDefinitions.BenthicBacterialReduction; % fraction of benthic detritus returned to DIN (assumed no direct return to surface mixed layer) (scaler)
EwE_DetritusFate          = ModelDefinitions.EwE_DetritusFate; % EwE detritus fate (NOT the ECOTRAN parameters); note transpose to stack of horizontal vectors

ExcretionFate             = ModelDefinitions.ExcretionFate; % row 1 = surface mixed layer; row 2 = sub-surface; (2 horizontal vectors)
PhytoUptake_NO3           = ModelDefinitions.PhytoUptake_NO3; % row 1 = fraction of NO3 to small phytoplankton; row 2 = fraction of NO3 to large phytoplankton; (vertical vector)
PhytoUptake_NH4           = ModelDefinitions.PhytoUptake_NH4; % row 1 = fraction of NH4 to small phytoplankton; row 2 = fraction of NH4 to large phytoplankton; (vertical vector)
Oxidation_NH4             = ModelDefinitions.Oxidation_NH4; % fraction of NH4 produced oxidized directly back to NO3 abiologically; this should take precedence over phytoplankton uptake of NH4 in code below; (vertical vector)

GroupType                 = ModelDefinitions.GroupType;
GroupType_nutrients       = ModelDefinitions.GroupType_nutrients;
GroupType_EggsAndDetritus = ModelDefinitions.GroupType_EggsAndDetritus;
AggLabel                  = ModelDefinitions.AggLabel;
AggLabel_nutrients        = ModelDefinitions.AggLabel_nutrients;
AggLabel_EggsAndDetritus  = ModelDefinitions.AggLabel_EggsAndDetritus;

looky_PrimaryProducers    = ModelDefinitions.looky_PrimaryProducers;
looky_eggs                = ModelDefinitions.looky_eggs;
looky_detritus            = ModelDefinitions.looky_detritus;
looky_PelagicDetritus     = ModelDefinitions.looky_PelagicDetritus;
looky_BenthicDetritus     = ModelDefinitions.looky_BenthicDetritus;
looky_EggsAndDetritus     = ModelDefinitions.looky_EggsAndDetritus;
looky_fisheries           = ModelDefinitions.looky_fisheries;
looky_consumers           = ModelDefinitions.looky_consumers;
looky_plgcBacteria        = ModelDefinitions.looky_plgcBacteria;
looky_bnthBacteria        = ModelDefinitions.looky_bnthBacteria;
looky_OffalInDetritus     = ModelDefinitions.looky_OffalInDetritus;
looky_PlgcDetrInDetritus  = ModelDefinitions.looky_PlgcDetrInDetritus;
looky_BnthcDetrInDetritus = ModelDefinitions.looky_BnthcDetrInDetritus;
looky_EggsInDetritus      = ModelDefinitions.looky_EggsInDetritus;
looky_DetrInDetritus      = ModelDefinitions.looky_DetrInDetritus;

num_NitrogenNutrients     = ModelDefinitions.num_NitrogenNutrients;
num_PrimaryProducers      = ModelDefinitions.num_PrimaryProducers;
num_eggs                  = ModelDefinitions.num_eggs;
num_detritus              = ModelDefinitions.num_detritus;
num_PelagicDetritus       = ModelDefinitions.num_PelagicDetritus;
num_BenthicDetritus       = ModelDefinitions.num_BenthicDetritus;
num_EggsAndDetritus       = ModelDefinitions.num_EggsAndDetritus;
num_consumers             = ModelDefinitions.num_consumers;
num_bacteria              = ModelDefinitions.num_bacteria;
num_fisheries             = ModelDefinitions.num_fisheries;

MonteCarlo_rows           = ModelDefinitions.MonteCarlo_rows;
MonteCarlo_layers         = ModelDefinitions.MonteCarlo_layers;
MonteCarloDiet_rows       = ModelDefinitions.MonteCarloDiet_rows;
MonteCarloDiet_clms       = ModelDefinitions.MonteCarloDiet_clms;

% step 1b: parameter values of the current MonteCarlo models
EwE_Biomass               = CurrentModel.EwE_Biomass;
EwE_PB                    = CurrentModel.EwE_PB;
EwE_QB                    = CurrentModel.EwE_QB;
EwE_PQ                    = CurrentModel.EwE_PQ; % production efficiency = (P_p / Q_p) = ((M2_p + EM_p + BA_p + M0_p) / Q_p) = growth efficiency = fraction of consumption by each consumer, c, going to production
EwE_AE                    = CurrentModel.EwE_AE; % assimilation efficiency = ((P_p + Met_p) / Q_p) = fraction of consumption by each consumer, c, going to production and metabolism
EwE_BA                    = CurrentModel.EwE_BA;
EwE_EM                    = CurrentModel.EwE_EM;
EwE_EE                    = CurrentModel.EwE_EE;    
working_diet              = CurrentModel.working_diet;
working_consumption       = CurrentModel.working_consumption;
% EwE_Landings              = CurrentModel.EwE_Landings'; QQQ error transpose --- % note transpose (matrix: groups X gear type)
% EwE_Discards              = CurrentModel.EwE_Discards'; % note transpose (matrix: groups X gear type)
% EwE_TotalFishery          = CurrentModel.EwE_TotalFishery; % note NO transpose (matrix: gear type X groups)
EwE_Landings              = CurrentModel.EwE_Landings; % (t/km2/y); (2D matrix: groups X gear)
EwE_Discards              = CurrentModel.EwE_Discards; % (t/km2/y); (2D matrix: groups X gear)
EwE_TotalFishery          = CurrentModel.EwE_TotalFishery; % (t/km2/y); (2D matrix: groups X gear)





% *************************************************************************
% STEP 3: prep diet and consumption matrices; add fisheries as predator and prey (unitless fractions, 0 to 1)
% step 3a: remove import diet and import consumption
EwE_importdiet                                        = working_diet(end, :); % save import diet
working_diet(end, :)                                  = []; % remove import prey (applies only to seagulls & cormorants in NCC)
EwE_importdiet(1, (end+1):(end+num_fisheries))        = 0; % append import fisheries as 0
EwE_importconsumption                                 = working_consumption(end, :); % retain import consumption (seagulls & cormorants in NCC)
working_consumption(end, :)                           = []; % remove import prey from consumption matrix (seagulls & cormorants)
EwE_importconsumption(1, (end+1):(end+num_fisheries)) = 0; % append import fisheries as 0

% step 3b: for each gear-type, append fisheries (landing + discards) to diet and consumption matrix
rows_diet                          = MonteCarloDiet_rows - 2 + num_fisheries; % rows in final diet matrix; -2 from rows for import and header
clms_diet                          = MonteCarloDiet_clms - 1 + num_fisheries; % clms in final diet matrix; -1 from clms for header
EwE_diet                           = zeros(rows_diet, clms_diet); % initialize DietMatrix_NoCannibalism matrix
DietMatrix_NoCannibalism           = zeros(rows_diet, clms_diet); % initialize EwE_diet matrix
EwE_consumption                    = zeros(rows_diet, clms_diet); % initialize EwE_consumption matrix
EwE_TotalConsumption               = zeros(1, clms_diet); % initialize 
cannibalism_vector                 = zeros(1, clms_diet); % initialize
EwE_TotalCannibalism               = zeros(1, clms_diet); % initialize
EwE_TotalConsumption_NoCannibalism = zeros(1, clms_diet); % initialize

ConsumptionMatrix                  = zeros(rows_diet, clms_diet); % initialize temporary Consumption matrix
ConsumptionMatrix_NoCannibalism    = zeros(rows_diet, clms_diet); % initialize temporary ConsumptionMatrix_NoCannibalism matrix
EwE_TotalPredation_WithCannibalism = zeros(rows_diet, 1); % initialize
EwE_TotalPredation_NoCannibalism   = zeros(rows_diet, 1); % initialize

current_diet                                                                            = working_diet; % QQQ dont need this name change
current_consumption                                                                     = working_consumption; % QQQ dont need this name change
current_EwE_TotalFishery                                                                = EwE_TotalFishery; % QQQ dont need this name change
EwE_diet(1:MonteCarlo_rows, 1:MonteCarlo_rows)                                          = current_diet; % re-install first MonteCarlo diet matrix (importdiet already removed)
EwE_consumption(1:MonteCarlo_rows, 1:MonteCarlo_rows)                                   = current_consumption; % re-install first MonteCarlo consumption matrix (importconsumption already removed)
% EwE_diet(1:MonteCarlo_rows, (MonteCarlo_rows+1):(MonteCarlo_rows+num_fisheries))        = current_EwE_TotalFishery'; % transpose error --- append fisheries as columns to end of EwE_diet matrix
% EwE_consumption(1:MonteCarlo_rows, (MonteCarlo_rows+1):(MonteCarlo_rows+num_fisheries)) = current_EwE_TotalFishery'; % append fisheries as columns to end of EwE_consumption matrix
EwE_diet(1:MonteCarlo_rows, (MonteCarlo_rows+1):(MonteCarlo_rows+num_fisheries))        = current_EwE_TotalFishery; % append fisheries as columns to end of EwE_diet matrix
EwE_consumption(1:MonteCarlo_rows, (MonteCarlo_rows+1):(MonteCarlo_rows+num_fisheries)) = current_EwE_TotalFishery; % append fisheries as columns to end of EwE_consumption matrix

% rescale diet clms to sum to 1; This makes fishery column into fractions of total fishery and corrects for removing the trace of import diet
for clms_loop = 1:clms_diet; 
	EwE_diet(:, clms_loop) = EwE_diet(:, clms_loop) ./ sum(EwE_diet(:, clms_loop));
end
EwE_diet(isnan(EwE_diet)) = 0; % convert NaNs (phyto & detritus groups) to 0 

% step 3c: remove cannibalism from diet matrix
[DietMatrix_NoCannibalism(1:rows_diet, 1:clms_diet), cannibalism_vector(1, 1:clms_diet)] = f_RedistributeCannibalism(EwE_diet(:, :)); % remove cannibalism terms on diagonal of matrix EwE_diet;

% step 3d: total consumption by each consumer group, c; (t/km2/y); (horizontal vectors)
EwE_TotalConsumption(1, 1:clms_diet)               = sum(EwE_consumption(:, 1:clms_diet), 1); % total consumption of each consumer group, c; (horizontal vector); includes cannibalism consumption;
EwE_TotalCannibalism(1, 1:clms_diet)               = cannibalism_vector(1, 1:clms_diet) .* EwE_TotalConsumption(1, :); % total cannibalism within each consumer group, c; (horizontal vector); (t/km2/yr)
EwE_TotalConsumption_NoCannibalism(1, 1:clms_diet) = EwE_TotalConsumption(1, 1:clms_diet) - EwE_TotalCannibalism(1, 1:clms_diet);

% step 3e: calculate total absolute predation on each producer, p; M2_p = sigma(b_pc * C_c) for all predators, c; (t/km2/y); (vertical vector)
% Note that this method is based on the original diet matrix NOT the modified diet matrix that removes cannibalism.
% The result is that the total predation on each producer group p is reduced by the level of cannibalism and that the predation on 
% non-cannibalized groups is NOT increased in compensation (as would happen if the modified diet were to be applied).
for prey_loop = 1:rows_diet % (1 to p)
	ConsumptionMatrix(prey_loop, 1:clms_diet)               = EwE_diet(prey_loop, 1:clms_diet) .* EwE_TotalConsumption(1, 1:clms_diet); % flow to detritus groups is 0 in the ConsumptionMatrix (because detritus columns = 0 in the diet matrix)
	ConsumptionMatrix_NoCannibalism(prey_loop, 1:clms_diet) = ConsumptionMatrix(prey_loop, 1:clms_diet);
	ConsumptionMatrix_NoCannibalism(prey_loop, prey_loop)   = 0; % set cannibalism diagonal values to 0
end
EwE_TotalPredation_WithCannibalism(1:rows_diet, 1) = sum(ConsumptionMatrix(1:rows_diet, 1:clms_diet), 2); % total predation ON each producer group, p; includes cannibalism; (M2_p); (vertical vector); (t/km2/yr)
EwE_TotalPredation_NoCannibalism(1:rows_diet, 1)   = sum(ConsumptionMatrix_NoCannibalism(1:rows_diet, 1:clms_diet), 2); % total predation ON each producer group, p; does NOT include cannibalism; (M2_p); (vertical vector); (t/km2/yr)





% *************************************************************************
% STEP 4: calculate production rates, Bioenergetic Efficiencies, Ecotrophic Efficiencies, Transfer Efficiencies from EwE (t/km2/yr); (vertical vector)
% NOTE: when using MonteCarlo: EwE_Production for eggs = 0, EcotrophicEfficiency terms for eggs = NaN, TransferEfficiency terms for eggs = NaN
% step 4a: Ecotrophic Efficiencies (distribution of production) & Transfer Efficiencies (distribution of consumption; fractions of Q_p)
EwE_Production                 = zeros(rows_diet, 1); % initialize
EcotrophicEfficiency_predation = zeros(rows_diet, 1); % initialize
EcotrophicEfficiency_BA        = zeros(rows_diet, 1); % initialize
EcotrophicEfficiency_EM        = zeros(rows_diet, 1); % initialize
EcotrophicEfficiency           = zeros(rows_diet, 1); % initialize
TransferEfficiency             = zeros(rows_diet, 1); % initialize

EwE_Production                 = EwE_Biomass .* EwE_PB; % production rate of each prey group, p; (P_p); (t/km2/y); (vertical vector); (Must re-calc production here because production rates not saved directly for each MonteCarlo model)
EcotrophicEfficiency_predation = EwE_TotalPredation_NoCannibalism ./ EwE_Production; % (M2_p / P_p) = fraction of production by each group, c, passed upwards in food web via predation; note omission of cannibalism
EcotrophicEfficiency_BA        = EwE_BA                           ./ EwE_Production; % (BA_p / P_p) = fraction of production by each group, c, directed to biomass accumulation
EcotrophicEfficiency_EM        = EwE_EM                           ./ EwE_Production; % (EM_p / P_p) = fraction of production by each group, c, directed to emigration (immigration is negative production); will = 1 for fisheries
EcotrophicEfficiency           = EcotrophicEfficiency_predation + EcotrophicEfficiency_BA + EcotrophicEfficiency_EM; % (EE_p = (M2_p + EM_p + BA_p) / P_p) = Ecotrophic Efficiency as defined by EwE; note that the omission of cannibalism from the total predation term corrects the EcotrophicEfficiency for the omission of cannibalism in the PredationMatrix (calculated below)
TransferEfficiency             = EcotrophicEfficiency .* EwE_PQ; % ((M2_p + EM_p + BA_p) / Q_p) = fraction of consumption by each group, c, passed upwards in food web via predation, accumulation, and emigration





% *************************************************************************
% STEP 5: construct energy flow budgets (unitless fractions, 0 to 1); (horizontal vectors, length = p)
% There are three energy flow budgets involved in the construction of the E2E model:
%	A) bioenergetic budget (= consumption budget): fraction of consumption by each producer group, p, going to production, feces (non-assimilated consumption), or metabolism.
%	B) production budget: fraction of total production of each producer, p, going to predation, other mortality (non-consumed production), emigration (or immigration, physical transport), and biomass accumulation.
%	C) predation budget: fraction of total predation on each producer, p, going to each consumer, c.

BioenergeticBudget_production      = zeros(1, clms_diet); % initialize
BioenergeticBudget_feces           = zeros(1, clms_diet); % initialize
BioenergeticBudget_metabolism      = zeros(1, clms_diet); % initialize
BioenergeticBudget_OtherMortDetail = zeros(num_EggsAndDetritus, clms_diet); % initialize
BioenergeticBudget_FecesDetail     = zeros(num_EggsAndDetritus, clms_diet); % initialize
ProductionBudget_predation         = zeros(1, clms_diet); % initialize
ProductionBudget_OtherMortality    = zeros(1, clms_diet); % initialize
ProductionBudget_BA                = zeros(1, clms_diet); % initialize
ProductionBudget_EM                = zeros(1, clms_diet); % initialize
ProductionBudget_OtherMortDetail   = zeros(num_EggsAndDetritus, clms_diet); % initialize
PredationBudget                    = zeros(rows_diet, clms_diet); % initialize

% step 5a: calculate bioenergetic budget for each producer, p = consumption budget = the fraction of consumption (Q) going to production + feces (non-assimilated consumption) + metabolism
BioenergeticBudget_production      = EwE_PQ';
BioenergeticBudget_feces           = (1 - EwE_AE)';
BioenergeticBudget_metabolism      = (EwE_AE - EwE_PQ)'; % fraction of consumption going to metabolism (NH4 production); Metabolism = 1 - PQ - feces = (1 - (EwE_PQ + (1-EwE_AE)))

% STEP 5b: calculate production budget for each group, p; (p rows by 4 clms); this is the fraction of production going to predation, other mortality (non-consumed production), emigration (or immigration, physical transport), or biomass accumulation.
% NOTE: when using MonteCarlo: ProductionBudget terms for eggs = inf and NaN
% NOTE: ProductionBudget terms are defined by the EwE EcotrophicEfficiency terms (as is the BioenergeticBudget_OtherMortDetail & BioenergeticBudget_OtherMortality)
ProductionBudget_predation         = EcotrophicEfficiency_predation'; % (M2_p / P_p)
ProductionBudget_OtherMortality    = (1 - EcotrophicEfficiency)'; % (M0_p / P_p) = fraction of production going to other mortality (non-consumed production); note that elimination of cannibalism predation results in increased production to 'other mortality';
ProductionBudget_BA                = EcotrophicEfficiency_BA'; % (BA_p / P_p)
ProductionBudget_EM                = EcotrophicEfficiency_EM'; % (EM_p / P_p); includes physical transport out of model domain; immigration is negative production, emigration is positive production;

% step 5c: OtherMortality fate (non-consumed production) & feces fate, distribute among eggs & detritus
% NOTE: when using MonteCarlo: ProductionBudget and ProductionAbsolute terms for eggs = NaN
for OtherMort_loop1 = 1:num_EggsAndDetritus
    BioenergeticBudget_FecesDetail(OtherMort_loop1, 1:clms_diet)     = BioenergeticBudget_feces(1, 1:clms_diet)        .* EwE_DetritusFate(OtherMort_loop1, 1:clms_diet); % (units of fraction of total group consumption)
	ProductionBudget_OtherMortDetail(OtherMort_loop1, 1:clms_diet)   = ProductionBudget_OtherMortality(1, 1:clms_diet) .* EwE_DetritusFate(OtherMort_loop1, 1:clms_diet); % (units of fraction of total group production)
    % rescale ProductionBudget_OtherMortDetail (in production units) to get BioenergeticBudget_OtherMortDetail (in consumption units) (multiply by production efficiency, P/Q)
    % NOTE: when using MonteCarlo: BioenergeticBudget_OtherMortDetail terms for eggs = NaN; this gets fixed in STEP 7
    BioenergeticBudget_OtherMortDetail(OtherMort_loop1, 1:clms_diet) = ProductionBudget_OtherMortDetail(OtherMort_loop1, 1:clms_diet) .* EwE_PQ'; % (M0_j / Q_j) = (M0_j / P_j) * (P_j / Q_j)
end

% step 5d: calculate predation budget (a.k.a.: PRED_cp, predator matrix, bottom-up matrix, inverse transposition); (matrix sized c x p , each column sums to 1 when there is predation on p)
% NOTE: good for eggs
PredationBudget = f_CalcPredationMatrix(EwE_TotalConsumption_NoCannibalism, DietMatrix_NoCannibalism); % for each producer, p, and consumer, c: ((b_pc * Q_c) / M2_p)) = the fraction of total predation on each producer, p, going to each consumer, c.





% *************************************************************************
% STEP 6: EwE egg correction --- use when eggs are treated as a detritus group in EwE
%         this code removes feces contribution to eggs and replaces it with an increased OtherMortality contribution to eggs; egg production
%         remains the same, but AE, PQ, EE, BioenergeticBudget, & ProductionBudget terms are adjusted
% (QQQ in future, allow for forcing egg, gamete, and live-birth as a Budget term and then remove eggs as an EwE detritus term)
new_EwE_AE                            = zeros(rows_diet, 1); % initialize
new_EwE_PQ                            = zeros(rows_diet, 1); % initialize
BioenergeticBudget_ProductionOriginal = BioenergeticBudget_production; % will need to hold on to original BioenergeticBudget_production for a while

% step 6a: move egg flow from feces to OtherMort, and set eggs to 0 in feces
EggsInOtherMort = BioenergeticBudget_OtherMortDetail(looky_EggsInDetritus, 1:clms_diet);
EggsInFeces     = BioenergeticBudget_FecesDetail(looky_EggsInDetritus, 1:clms_diet);
EggsInOtherMort = EggsInOtherMort + EggsInFeces;
EggsInFeces     = EggsInFeces * 0;

BioenergeticBudget_OtherMortDetail(looky_EggsInDetritus, 1:clms_diet) = EggsInOtherMort;
BioenergeticBudget_FecesDetail(looky_EggsInDetritus, 1:clms_diet)     = EggsInFeces;

% step 6b: calculate egg production and update ProductionBudget, EwE_Production, and BioenergeticBudget_OtherMortDetail
egg_production     = zeros(num_eggs, clms_diet); % initialize
ProductionAbs_eggs = zeros(num_eggs, 1); % initialize
PredationAbs_eggs  = zeros(num_eggs, 1); % initialize

for egg_loop = 1:num_eggs
    egg_production(egg_loop, 1:clms_diet) = BioenergeticBudget_OtherMortDetail(looky_EggsInDetritus(egg_loop), 1:clms_diet) .* EwE_TotalConsumption;
    ProductionAbs_eggs(egg_loop)          = sum(egg_production(egg_loop, looky_consumers), 2); % total egg production
    PredationAbs_eggs(egg_loop)           = EwE_TotalPredation_NoCannibalism(looky_eggs(egg_loop)); % keep or ignore cannibalism, it doesn't matter for eggs
    EwE_Production(looky_eggs(egg_loop))  = ProductionAbs_eggs(egg_loop); % input egg production values into EwE_Production vector (vertical vector)
    
    ProductionBudget_predation(looky_eggs(egg_loop))      = PredationAbs_eggs(egg_loop) / ProductionAbs_eggs(egg_loop);
    ProductionBudget_OtherMortality(looky_eggs(egg_loop)) = 1 - (PredationAbs_eggs(egg_loop) / ProductionAbs_eggs(egg_loop));
    ProductionBudget_BA(looky_eggs(egg_loop))             = 0; % forced assuming egg BA = 0 (QQQ in future a better way?)    
    ProductionBudget_EM(looky_eggs(egg_loop))             = 0; % forced assuming egg EM = 0 (QQQ in future a better way?)  
    
end
ProductionBudget(1:4, 1:clms_diet) = [ProductionBudget_predation; ProductionBudget_OtherMortality; ProductionBudget_BA; ProductionBudget_EM];
ProductionBudget_OtherMortOriginal = ProductionBudget_OtherMortality; % will need to hold on to the original ProductionBudget_OtherMortality for a while

for OtherMort_loop4 = 1:num_EggsAndDetritus
	BioenergeticBudget_OtherMortDetail(OtherMort_loop4, looky_eggs) = ProductionBudget_OtherMortality(1, looky_eggs) .* EwE_DetritusFate(OtherMort_loop4, looky_eggs); % (units of fraction of total group production)
end

% step 6c: make adjustments to AE, ProductionBudget, and EcotrophicEfficiency since eggs defined as EwE detritus has been "stealing" production from feces to create eggs
% BioenergeticBudget
BioenergeticBudget_OtherMortTotal = sum(BioenergeticBudget_OtherMortDetail, 1);
BioenergeticBudget_FecesTotal     = sum(BioenergeticBudget_FecesDetail, 1);
new_EwE_AE                        = 1 - BioenergeticBudget_FecesTotal';
new_EwE_PQ                        = BioenergeticBudget_production' + (new_EwE_AE - EwE_AE); % original production (P/Q) + increased production from increased re-estimate of AE 
BioenergeticBudget_production     = new_EwE_PQ';
BioenergeticBudget_feces          = (1 - new_EwE_AE)';
% BioenergeticBudget_metabolism     = (new_EwE_AE - new_EwE_PQ)'; % re-calculation is not necessary, metabolism will not change during EwE egg correction (I checked to make sure)

% ProductionBudget
ProductionBudget_total            = sum(ProductionBudget(1:4, 1:clms_diet), 1);
ProductionBudget_NewTotal         = ProductionBudget_total .* (BioenergeticBudget_production ./ BioenergeticBudget_ProductionOriginal);
ProductionBudget_OtherMortality   = ProductionBudget_OtherMortOriginal + (ProductionBudget_NewTotal - 1);
ProductionBudget_OtherMortality   = ProductionBudget_OtherMortality ./ ProductionBudget_NewTotal; % re-normalize ProductionBudget elements
ProductionBudget_predation        = ProductionBudget_predation      ./ ProductionBudget_NewTotal; % re-normalize ProductionBudget elements
ProductionBudget_BA               = ProductionBudget_BA             ./ ProductionBudget_NewTotal; % re-normalize ProductionBudget elements
ProductionBudget_EM               = ProductionBudget_EM             ./ ProductionBudget_NewTotal; % re-normalize ProductionBudget elements

% update ProductionBudget_OtherMortDetail
for OtherMort_loop3 = 1:num_EggsAndDetritus 
	ProductionBudget_OtherMortDetail(OtherMort_loop3, 1:clms_diet) = BioenergeticBudget_OtherMortDetail(OtherMort_loop3, 1:clms_diet) .* (1 ./ new_EwE_PQ'); % (M0_j / Q_j) = (M0_j / P_j) * (P_j / Q_j)
end

% update EwE_AE and EwE_PQ
EwE_AE = new_EwE_AE;
EwE_PQ = new_EwE_PQ;

% update EcotrophicEfficiency terms (only EcotrophicEfficiency_predation has changed); note that TE does not change
EcotrophicEfficiency_predation = ProductionBudget_predation';
EcotrophicEfficiency_BA        = ProductionBudget_BA';
EcotrophicEfficiency_EM        = ProductionBudget_EM';
EcotrophicEfficiency           = EcotrophicEfficiency_predation + EcotrophicEfficiency_BA + EcotrophicEfficiency_EM; % (EE_p = (M2_p + EM_p + BA_p) / P_p) = Ecotrophic Efficiency as defined by EwE; note that the omission of cannibalism from the total predation term corrects the EcotrophicEfficiency for the omission of cannibalism in the PredationMatrix (calculated below)
TransferEfficiency             = EcotrophicEfficiency .* EwE_PQ; % ((M2_p + EM_p + BA_p) / Q_p) = fraction of consumption by each group, c, passed upwards in food web via predation, accumulation, and emigration

% step 6d: rescale predation matrix (in predation units) in terms of consumption (multiply by transfer efficiency)
BioenergeticBudget_predation = zeros(rows_diet, clms_diet); % initialize temporary BioenergeticBudget_predation matrix
for prey_loop = 1:clms_diet % (1 to p)
	BioenergeticBudget_predation(prey_loop, 1:clms_diet) = (PredationBudget(prey_loop, :) .* EcotrophicEfficiency_predation') .* EwE_PQ'; % ((b_ji * Q_i) / Q_j) = ((b_ji * Q_i) / M2_j) * (M2_j / P_j) * (P_j / Q_j)
end

% step 6e: rescale ProductionBudget_BA, ProductionBudget_EM (in production units) in terms of consumption (multiply by production efficiency, P/Q)
BioenergeticBudget_BA = zeros(1, clms_diet); % initialize
BioenergeticBudget_EM = zeros(1, clms_diet); % initialize
BioenergeticBudget_BA = ProductionBudget_BA .* EwE_PQ'; % (BA_j / Q_j) = (BA_j / P_j) * (P_j / Q_j)
BioenergeticBudget_EM = ProductionBudget_EM .* EwE_PQ'; % (EM_j / Q_j) = (EM_j / P_j) * (P_j / Q_j)





% *************************************************************************
% STEP 7: build terminal detritus pools------------------------------------
BioenergeticBudget_detritus = zeros(num_EggsAndDetritus, clms_diet); % initialize (budget in terms of consumption)

% step 7a: pool OtherMortality and pool feces fractions rows of BioenergeticBudget; exclude eggs & other non-terminal detritus groups
temp_OtherMortTotal = sum(BioenergeticBudget_OtherMortDetail([looky_PlgcDetrInDetritus; looky_BnthcDetrInDetritus], 1:clms_diet), 1);
temp_FecesTotal     = sum(BioenergeticBudget_FecesDetail(    [looky_PlgcDetrInDetritus; looky_BnthcDetrInDetritus], 1:clms_diet), 1);

% step 7b: apply ECOTRAN detritus fates
TerminalDetritusBudget_pelagic = (temp_OtherMortTotal .* DetritusFate_senescence(1, :)) + (temp_FecesTotal .* DetritusFate_feces(1, :));
TerminalDetritusBudget_benthic = (temp_OtherMortTotal .* DetritusFate_senescence(2, :)) + (temp_FecesTotal .* DetritusFate_feces(2, :));

% step 7c: pool feces and OtherMortality in the BioenergeticBudget
BioenergeticBudget_detritus(1:num_EggsAndDetritus, 1:clms_diet) = BioenergeticBudget_OtherMortDetail + BioenergeticBudget_FecesDetail;

% step 7d: zero out all terminal detritus groups in original EwE detritus set (but don't delete them yet)
BioenergeticBudget_detritus([looky_PlgcDetrInDetritus; looky_BnthcDetrInDetritus], 1:clms_diet) = 0;

% step 7e: replace eggs & detritus rows in BioenergeticBudget_predation with BioenergeticBudget_detritus % YYY start here
BioenergeticBudget_predation(looky_EggsAndDetritus, 1:clms_diet) = BioenergeticBudget_detritus;

% step 7f: append TerminalDetritusBudget_pelagic & TerminalDetritusBudget_benthic rows onto end of BioenergeticBudget_predation
BioenergeticBudget_predation((rows_diet+1):(rows_diet+2), 1:clms_diet) = [TerminalDetritusBudget_pelagic; TerminalDetritusBudget_benthic];

% step 7g: lateral pooling of EwE terminal detritus columns in BioenergeticBudget_predation
temp_DetritusAbs_pelagic = zeros((rows_diet+2), num_PelagicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
temp_DetritusAbs_benthic = zeros((rows_diet+2), num_BenthicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
for consumer_loop = 1:(rows_diet+2) % (1 to c); (+2 for appended TerminalDetritusBudget)
    temp_DetritusAbs_pelagic(consumer_loop, :) = BioenergeticBudget_predation(consumer_loop, looky_PelagicDetritus) .* EwE_TotalConsumption_NoCannibalism(1, looky_PelagicDetritus); % absolute consumption (alternatively use EwE_Production(looky_PelagicDetritus, layer_loop7)' <<-note transpose)
	temp_DetritusAbs_benthic(consumer_loop, :) = BioenergeticBudget_predation(consumer_loop, looky_BenthicDetritus) .* EwE_TotalConsumption_NoCannibalism(1, looky_BenthicDetritus); % absolute consumption (alternatively use EwE_Production(looky_BenthicDetritus, layer_loop7)' <<-note transpose)
end
temp_DetritusClm_pelagic = sum(temp_DetritusAbs_pelagic, 2); % add consumption laterally
temp_DetritusClm_benthic = sum(temp_DetritusAbs_benthic, 2); % add consumption laterally
temp_DetritusClm_pelagic = temp_DetritusClm_pelagic ./ sum(temp_DetritusClm_pelagic, 1); % re-normalize; now back in budget format (values 0 to 1)
temp_DetritusClm_benthic = temp_DetritusClm_benthic ./ sum(temp_DetritusClm_benthic, 1); % re-normalize; now back in budget format (values 0 to 1)
temp_DetritusClm_pelagic(isnan(temp_DetritusClm_pelagic)) = 0; % filter out any div0 errors (should be rare)
temp_DetritusClm_benthic(isnan(temp_DetritusClm_benthic)) = 0; % filter out any div0 errors (should be rare)

% step 7h: append the 2 EwE terminal detritus columns to BioenergeticBudget_predation, GroupType, AggLabel
BioenergeticBudget_predation(:, (clms_diet+1):(clms_diet+2)) = [temp_DetritusClm_pelagic temp_DetritusClm_benthic];
GroupType((rows_diet+1):(rows_diet+2))                       = [ModelDefinitions.GroupTypeDef_terminalPlgcDetr; ModelDefinitions.GroupTypeDef_terminalBnthDetr]; % append to GroupType codes
AggLabel((rows_diet+1):(rows_diet+2))                        = {'pelagic detritus'; 'benthic detritus'};  % append to AggLabel

% step 7i: lateral pooling of EwE terminal detritus columns in ProductionBudget
temp_ProdAbs_predation_pelagic = ProductionBudget_predation(1, looky_PelagicDetritus)      .* EwE_Production(looky_PelagicDetritus)'; % absolute production
temp_ProdAbs_predation_benthic = ProductionBudget_predation(1, looky_BenthicDetritus)      .* EwE_Production(looky_BenthicDetritus)'; % absolute production
temp_ProdAbs_OtherMort_pelagic = ProductionBudget_OtherMortality(1, looky_PelagicDetritus) .* EwE_Production(looky_PelagicDetritus)'; % absolute production
temp_ProdAbs_OtherMort_benthic = ProductionBudget_OtherMortality(1, looky_BenthicDetritus) .* EwE_Production(looky_BenthicDetritus)'; % absolute production
temp_ProdAbs_BA_pelagic        = ProductionBudget_BA(1, looky_PelagicDetritus)             .* EwE_Production(looky_PelagicDetritus)'; % absolute production
temp_ProdAbs_BA_benthic        = ProductionBudget_BA(1, looky_BenthicDetritus)             .* EwE_Production(looky_BenthicDetritus)'; % absolute production
temp_ProdAbs_EM_pelagic        = ProductionBudget_EM(1, looky_PelagicDetritus)             .* EwE_Production(looky_PelagicDetritus)'; % absolute production
temp_ProdAbs_EM_benthic        = ProductionBudget_EM(1, looky_BenthicDetritus)             .* EwE_Production(looky_BenthicDetritus)'; % absolute production

ProdClm_predation_pelagic = sum(temp_ProdAbs_predation_pelagic, 2) / sum(EwE_Production(looky_PelagicDetritus)); % add production laterally
ProdClm_predation_benthic = sum(temp_ProdAbs_predation_benthic, 2) / sum(EwE_Production(looky_BenthicDetritus)); % add production laterally
ProdClm_OtherMort_pelagic = sum(temp_ProdAbs_OtherMort_pelagic, 2) / sum(EwE_Production(looky_PelagicDetritus)); % add production laterally
ProdClm_OtherMort_benthic = sum(temp_ProdAbs_OtherMort_benthic, 2) / sum(EwE_Production(looky_BenthicDetritus)); % add production laterally
ProdClm_BA_pelagic        = sum(temp_ProdAbs_BA_pelagic, 2)        / sum(EwE_Production(looky_PelagicDetritus)); % add production laterally
ProdClm_BA_benthic        = sum(temp_ProdAbs_BA_benthic, 2)        / sum(EwE_Production(looky_BenthicDetritus)); % add production laterally
ProdClm_EM_pelagic        = sum(temp_ProdAbs_EM_pelagic, 2)        / sum(EwE_Production(looky_PelagicDetritus)); % add production laterally
ProdClm_EM_benthic        = sum(temp_ProdAbs_EM_benthic, 2)        / sum(EwE_Production(looky_BenthicDetritus)); % add production laterally

% step 7j: append the 2 EwE terminal detritus columns to ProductionBudget_predation, ProductionBudget_OtherMortality, ProductionBudget_EM, and ProductionBudget_BA
ProductionBudget_predation(1, (clms_diet+1):(clms_diet+2))      = [ProdClm_predation_pelagic ProdClm_predation_benthic];
ProductionBudget_OtherMortality(1, (clms_diet+1):(clms_diet+2)) = [ProdClm_OtherMort_pelagic ProdClm_OtherMort_benthic];
ProductionBudget_BA(1, (clms_diet+1):(clms_diet+2))             = [ProdClm_BA_pelagic        ProdClm_BA_benthic];
ProductionBudget_EM(1, (clms_diet+1):(clms_diet+2))             = [ProdClm_EM_pelagic        ProdClm_EM_benthic];

% step 7k: lateral pooling of other EwE detritus terms in BioenergeticBudget_OtherMortDetail, ProductionAbs_OtherMortDetail
BioenergeticAbs_OtherMortDetail_pelagic = zeros(num_EggsAndDetritus, num_PelagicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
BioenergeticAbs_OtherMortDetail_benthic = zeros(num_EggsAndDetritus, num_BenthicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
ProductionAbs_OtherMortDetail_pelagic   = zeros(num_EggsAndDetritus, num_PelagicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
ProductionAbs_OtherMortDetail_benthic   = zeros(num_EggsAndDetritus, num_BenthicDetritus); % initialize each MonteCarlo_layer (absolute production; use for lateral pooling)
for detritus_loop = 1:num_EggsAndDetritus
	BioenergeticAbs_OtherMortDetail_pelagic(detritus_loop, 1:num_PelagicDetritus) = BioenergeticBudget_OtherMortDetail(detritus_loop, looky_PelagicDetritus) .* EwE_TotalConsumption_NoCannibalism(1, looky_PelagicDetritus); % absolute consumption (alternatively use EwE_Production(looky_PelagicDetritus, layer_loop7)' <<-note transpose)
	BioenergeticAbs_OtherMortDetail_benthic(detritus_loop, 1:num_BenthicDetritus) = BioenergeticBudget_OtherMortDetail(detritus_loop, looky_BenthicDetritus) .* EwE_TotalConsumption_NoCannibalism(1, looky_BenthicDetritus); % absolute consumption (alternatively use EwE_Production(looky_BenthicDetritus, layer_loop7)' <<-note transpose)
	ProductionAbs_OtherMortDetail_pelagic(detritus_loop, 1:num_PelagicDetritus)   = ProductionBudget_OtherMortDetail(detritus_loop, looky_PelagicDetritus)   .* EwE_Production(looky_PelagicDetritus)'; % absolute production; note transpose of EwE_Production to a horizontal vector; (t/km2/y)
	ProductionAbs_OtherMortDetail_benthic(detritus_loop, 1:num_BenthicDetritus)   = ProductionBudget_OtherMortDetail(detritus_loop, looky_BenthicDetritus)   .* EwE_Production(looky_BenthicDetritus)'; % absolute production; note transpose of EwE_Production to a horizontal vector; (t/km2/y)
end
BioenergeticClm_OtherMortDetail_pelagic = sum(BioenergeticAbs_OtherMortDetail_pelagic, 2);
BioenergeticClm_OtherMortDetail_benthic = sum(BioenergeticAbs_OtherMortDetail_benthic, 2);
BioenergeticClm_OtherMortDetail_pelagic = BioenergeticClm_OtherMortDetail_pelagic ./ sum(EwE_TotalConsumption_NoCannibalism(1, looky_PelagicDetritus)); % re-normalize; now back in budget format (values 0 to 1)
BioenergeticClm_OtherMortDetail_benthic = BioenergeticClm_OtherMortDetail_benthic ./ sum(EwE_TotalConsumption_NoCannibalism(1, looky_BenthicDetritus)); % re-normalize; now back in budget format (values 0 to 1)
BioenergeticClm_OtherMortDetail_pelagic(isnan(BioenergeticClm_OtherMortDetail_pelagic)) = 0; % filter out any div0 errors (should be rare)
BioenergeticClm_OtherMortDetail_benthic(isnan(BioenergeticClm_OtherMortDetail_benthic)) = 0; % filter out any div0 errors (should be rare)
ProductionClm_OtherMortDetail_pelagic   = sum(ProductionAbs_OtherMortDetail_pelagic, 2);
ProductionClm_OtherMortDetail_benthic   = sum(ProductionAbs_OtherMortDetail_benthic, 2);
ProductionClm_OtherMortDetail_pelagic   = ProductionClm_OtherMortDetail_pelagic ./ sum(EwE_Production(looky_PelagicDetritus)); % re-normalize; now back in budget format (values 0 to 1)
ProductionClm_OtherMortDetail_benthic   = ProductionClm_OtherMortDetail_benthic ./ sum(EwE_Production(looky_BenthicDetritus)); % re-normalize; now back in budget format (values 0 to 1)
ProductionClm_OtherMortDetail_pelagic(isnan(ProductionClm_OtherMortDetail_pelagic)) = 0; % filter out any div0 errors (should be rare)
ProductionClm_OtherMortDetail_benthic(isnan(ProductionClm_OtherMortDetail_benthic)) = 0; % filter out any div0 errors (should be rare)

% step 7l: append the 2 EwE terminal detritus columns to other BioenergeticBudget terms and ProductionBudget_OtherMortDetail
BioenergeticBudget_OtherMortDetail(1:num_EggsAndDetritus, (clms_diet+1):(clms_diet+2)) = [BioenergeticClm_OtherMortDetail_pelagic BioenergeticClm_OtherMortDetail_benthic];
BioenergeticBudget_FecesDetail(1:num_EggsAndDetritus, (clms_diet+1):(clms_diet+2))     = 0; % egg & detritus feces = 0
BioenergeticBudget_production(1, (clms_diet+1):(clms_diet+2))                          = 1; % terminal detritus production = 1
BioenergeticBudget_feces(1, (clms_diet+1):(clms_diet+2))                               = 0; % terminal detritus feces = 0
BioenergeticBudget_metabolism(1, (clms_diet+1):(clms_diet+2))                          = 0; % terminal detritus metabolism = 0
BioenergeticBudget_BA(1, (clms_diet+1):(clms_diet+2))                                  = BioenergeticBudget_BA(:, [looky_PelagicDetritus; looky_BenthicDetritus]);
BioenergeticBudget_EM(1, (clms_diet+1):(clms_diet+2))                                  = BioenergeticBudget_EM(:, [looky_PelagicDetritus; looky_BenthicDetritus]);
ProductionBudget_OtherMortDetail(1:num_EggsAndDetritus, (clms_diet+1):(clms_diet+2))   = [ProductionClm_OtherMortDetail_pelagic ProductionClm_OtherMortDetail_benthic];

% step 7m: pool EwE detritus in parameter rows
temp_Biomass_pelagic    = sum(EwE_Biomass(looky_PelagicDetritus), 1);
temp_Biomass_benthic    = sum(EwE_Biomass(looky_BenthicDetritus), 1);
temp_Landings_pelagic   = sum(EwE_Landings(looky_PelagicDetritus, :), 1); % note that looky_ addresses still work on this variable which does not include fisheries rows
temp_Landings_benthic   = sum(EwE_Landings(looky_BenthicDetritus, :), 1); % note that looky_ addresses still work on this variable which does not include fisheries rows
temp_Discards_pelagic   = sum(EwE_Discards(looky_PelagicDetritus, :), 1); % note that looky_ addresses still work on this variable which does not include fisheries rows
temp_Discards_benthic   = sum(EwE_Discards(looky_BenthicDetritus, :), 1); % note that looky_ addresses still work on this variable which does not include fisheries rows
temp_Production_pelagic = sum(EwE_Production(looky_PelagicDetritus), 1);
temp_Production_benthic = sum(EwE_Production(looky_BenthicDetritus), 1);
temp_PB_pelagic         = sum((EwE_PB(looky_PelagicDetritus) .* EwE_Production(looky_PelagicDetritus)), 1) ./  sum(EwE_Production(looky_PelagicDetritus), 1);
temp_PB_benthic         = sum((EwE_PB(looky_BenthicDetritus) .* EwE_Production(looky_BenthicDetritus)), 1) ./  sum(EwE_Production(looky_BenthicDetritus), 1);
temp_BA_pelagic         = sum((EwE_BA(looky_PelagicDetritus) .* EwE_Production(looky_PelagicDetritus)), 1) ./  sum(EwE_Production(looky_PelagicDetritus), 1);
temp_BA_benthic         = sum((EwE_BA(looky_BenthicDetritus) .* EwE_Production(looky_BenthicDetritus)), 1) ./  sum(EwE_Production(looky_BenthicDetritus), 1);
temp_EM_pelagic         = sum((EwE_EM(looky_PelagicDetritus) .* EwE_Production(looky_PelagicDetritus)), 1) ./  sum(EwE_Production(looky_PelagicDetritus), 1);
temp_EM_benthic         = sum((EwE_EM(looky_BenthicDetritus) .* EwE_Production(looky_BenthicDetritus)), 1) ./  sum(EwE_Production(looky_BenthicDetritus), 1);
temp_DtrFate_feces_plgc = mean(DetritusFate_feces(1:2, looky_PelagicDetritus), 2); % pool original ECOTRAN terminal detritus fate definitions
temp_DtrFate_feces_bnth = mean(DetritusFate_feces(1:2, looky_BenthicDetritus), 2);
temp_DtrFate_senes_plgc = mean(DetritusFate_senescence(1:2, looky_PelagicDetritus), 2); % pool original ECOTRAN terminal detritus fate definitions
temp_DtrFate_senes_bnth = mean(DetritusFate_senescence(1:2, looky_BenthicDetritus), 2);
temp_ExcretionFate_plgc = mean(ExcretionFate(1:2, looky_PelagicDetritus), 2); % pool original ECOTRAN excretion fate definitions
temp_ExcretionFate_bnth = mean(ExcretionFate(1:2, looky_BenthicDetritus), 2);

% step 7n: append terminal detritus rows to parameters
EwE_Biomass((rows_diet+1):(rows_diet+2))    = [temp_Biomass_pelagic;    temp_Biomass_benthic];
EwE_Landings((end+1):(end+2), :)            = [temp_Landings_pelagic;   temp_Landings_benthic];
EwE_Discards((end+1):(end+2), :)            = [temp_Discards_pelagic;   temp_Discards_benthic];
EwE_Production((rows_diet+1):(rows_diet+2)) = [temp_Production_pelagic; temp_Production_benthic];
EwE_PB((rows_diet+1):(rows_diet+2))         = [temp_PB_pelagic;         temp_PB_benthic]; 
EwE_QB((rows_diet+1):(rows_diet+2))         = [temp_PB_pelagic;         temp_PB_benthic]; % QB = PB
EwE_PQ((rows_diet+1):(rows_diet+2))         = [1;                       1];
EwE_AE((rows_diet+1):(rows_diet+2))         = [1;                       1];
EwE_BA((rows_diet+1):(rows_diet+2))         = [temp_BA_pelagic;         temp_BA_benthic];
EwE_EM((rows_diet+1):(rows_diet+2))         = [temp_EM_pelagic;         temp_EM_benthic];
DetritusFate_feces(1:2, (clms_diet+1):(clms_diet+2))      = [temp_DtrFate_feces_plgc  temp_DtrFate_feces_bnth];
DetritusFate_senescence(1:2, (clms_diet+1):(clms_diet+2)) = [temp_DtrFate_senes_plgc  temp_DtrFate_senes_bnth];
ExcretionFate(1:2, (clms_diet+1):(clms_diet+2))           = [temp_ExcretionFate_plgc  temp_ExcretionFate_bnth];

% step 7o: delete all EwE terminal detritus groups from BioenergeticBudget terms
BioenergeticBudget_predation([looky_PelagicDetritus; looky_BenthicDetritus], :)       = []; % delete rows
BioenergeticBudget_predation(:, [looky_PelagicDetritus; looky_BenthicDetritus])       = []; % delete clms
BioenergeticBudget_production(:, [looky_PelagicDetritus; looky_BenthicDetritus])      = []; % delete clms
BioenergeticBudget_feces(:, [looky_PelagicDetritus; looky_BenthicDetritus])           = []; % delete clms
BioenergeticBudget_metabolism(:, [looky_PelagicDetritus; looky_BenthicDetritus])      = []; % delete clms
BioenergeticBudget_BA(:, [looky_PelagicDetritus; looky_BenthicDetritus])              = []; % delete clms
BioenergeticBudget_EM(:, [looky_PelagicDetritus; looky_BenthicDetritus])              = []; % delete clms
BioenergeticBudget_OtherMortDetail(:, [looky_PelagicDetritus; looky_BenthicDetritus]) = []; % delete clms; (NOTE: entries for terminal detritus groups will be higher than in final BigMatrix because detritus oxidation is not included in this budget variable)
BioenergeticBudget_FecesDetail(:, [looky_PelagicDetritus; looky_BenthicDetritus])     = []; % delete clms

% step 7p: delete all EwE terminal detritus groups from ProductionBudget terms
ProductionBudget_predation(:, [looky_PelagicDetritus; looky_BenthicDetritus])       = []; % delete clms (should be 1 row)
ProductionBudget_OtherMortality(:, [looky_PelagicDetritus; looky_BenthicDetritus])  = []; % delete clms (should be 1 row)
ProductionBudget_BA(:, [looky_PelagicDetritus; looky_BenthicDetritus])              = []; % delete clms (should be 1 row)
ProductionBudget_EM(:, [looky_PelagicDetritus; looky_BenthicDetritus])              = []; % delete clms (should be 1 row)
ProductionBudget_OtherMortDetail(:, [looky_PelagicDetritus; looky_BenthicDetritus]) = []; % delete clms (> 1 row)

% step 7q: delete all EwE terminal detritus rows from parameters
EwE_Biomass([looky_PelagicDetritus; looky_BenthicDetritus])                      = []; % delete rows
EwE_Landings([looky_PelagicDetritus; looky_BenthicDetritus], :)                  = []; % delete rows
EwE_Discards([looky_PelagicDetritus; looky_BenthicDetritus], :)                  = []; % delete rows
EwE_Production([looky_PelagicDetritus; looky_BenthicDetritus])                   = []; % delete rows
EwE_PB([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
EwE_QB([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
EwE_PQ([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
EwE_AE([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
EwE_BA([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
EwE_EM([looky_PelagicDetritus; looky_BenthicDetritus])                           = []; % delete rows
DetritusFate_feces(:, [looky_PelagicDetritus; looky_BenthicDetritus])            = []; % delete clms
DetritusFate_senescence(:, [looky_PelagicDetritus; looky_BenthicDetritus])       = []; % delete clms
ExcretionFate(:, [looky_PelagicDetritus; looky_BenthicDetritus])                 = []; % delete clms

% step 7r: delete all EwE terminal detritus rows from GroupType, AggLabel
GroupType([looky_PelagicDetritus; looky_BenthicDetritus])                        = []; % delete rows from GroupType
AggLabel([looky_PelagicDetritus; looky_BenthicDetritus])                         = []; % delete rows from AggLabel

% step 7s: redefine EcotrophicEfficiency (old values written over)
EcotrophicEfficiency_predation = ProductionBudget_predation';
EcotrophicEfficiency_BA        = ProductionBudget_BA';
EcotrophicEfficiency_EM        = ProductionBudget_EM';
EcotrophicEfficiency           = EcotrophicEfficiency_predation + EcotrophicEfficiency_BA + EcotrophicEfficiency_EM;

% step 7t: clear obsolete addresses to prevent mistakes downstream
clear looky_* rows_diet clms_diet % all looky_ addresses, rows_diet, and clms_diet are now invalid, so clear them





% *************************************************************************
% STEP 8: build complete consumption budget matrix (BigMatrix)-------------
% step 8a: define BigMatrix size and initialize
[rows_BioBudg_pred, clms_BioBudg_pred, toss] = size(BioenergeticBudget_predation);

num_ECOTRAN_groups = num_NitrogenNutrients + rows_BioBudg_pred; % size of BigMatrix; (num_EggsAndDetritus changed with detritus shuffle)
BigMatrix          = zeros(num_ECOTRAN_groups, num_ECOTRAN_groups); % initialize

% step 8b: append nutrients to GroupType and AggLabel
GroupType          = [GroupType_nutrients; GroupType; ModelDefinitions.GroupTypeDef_BA; ModelDefinitions.GroupTypeDef_EM]; % put nutrients at start (+2 for BA & EM in budget variables)
AggLabel           = [AggLabel_nutrients; AggLabel; 'biomass accumulation'; 'emigration']; % (+2 for BA & EM)

% step 8c: update row addresses
looky_NO3             = find(GroupType        == ModelDefinitions.GroupTypeDef_NO3); % NO3
looky_PelagicNH4      = find(GroupType        == ModelDefinitions.GroupTypeDef_plgcNH4); % PelagicNH4
looky_BenthicNH4      = find(GroupType        == ModelDefinitions.GroupTypeDef_bnthNH4); % BenthicNH4
looky_Nutrients       = find(floor(GroupType) == ModelDefinitions.GroupTypeDef_ANYNitroNutr); % all nutrients
looky_PrimaryProducer = find(floor(GroupType) == ModelDefinitions.GroupTypeDef_ANYPrimaryProd);
looky_Eggs            = find(GroupType        == ModelDefinitions.GroupTypeDef_eggs); % eggs, gametes, or live young
looky_PelagicDetritus = find(GroupType        == ModelDefinitions.GroupTypeDef_terminalPlgcDetr); % pelagic detritus
looky_OffalDetritus   = find(GroupType        == ModelDefinitions.GroupTypeDef_offal); % offal detritus
looky_BenthicDetritus = find(GroupType        == ModelDefinitions.GroupTypeDef_terminalBnthDetr); % benthic detritus
looky_Detritus        = find(floor(GroupType) == ModelDefinitions.GroupTypeDef_ANYDetritus); % all detritus groups
looky_Fishery         = find(floor(GroupType) == ModelDefinitions.GroupTypeDef_fishery);
looky_BA              = find(GroupType        == ModelDefinitions.GroupTypeDef_BA);
looky_EM              = find(GroupType        == ModelDefinitions.GroupTypeDef_EM);
looky_EggsInDetritus  = ModelDefinitions.looky_EggsInDetritus; % these addresses are still valid, so retrieve them
looky_DetrInDetritus  = ModelDefinitions.looky_DetrInDetritus; % these addresses are still valid, so retrieve them

% step 8d: append predation matrix into BigMatrix
BigMatrix((num_NitrogenNutrients+1):(num_NitrogenNutrients+rows_BioBudg_pred), (num_NitrogenNutrients+1):(num_NitrogenNutrients+clms_BioBudg_pred)) = BioenergeticBudget_predation;

% step 8e: append abiotic oxidation of NH4 to NO3 into BigMatrix
BigMatrix(looky_NO3, looky_PelagicNH4) = Oxidation_NH4(1); % oxidation of pelagic NH4 to NO3
BigMatrix(looky_NO3, looky_BenthicNH4) = Oxidation_NH4(2); % oxidation of benthic NH4 to NO3

% step 8f: append nutrient flow to primary producers into BigMatrix
BigMatrix(looky_PrimaryProducer, looky_NO3)        = PhytoUptake_NO3; % distribute NO3 among primary producers
BigMatrix(looky_PrimaryProducer, looky_PelagicNH4) = PhytoUptake_NH4 .* (1 - Oxidation_NH4(1)); % distribute pelagic NH4 among primary producers; rescaled to allow NH4 oxidation to NO3
BigMatrix(looky_PrimaryProducer, looky_BenthicNH4) = PhytoUptake_NH4 .* (1 - Oxidation_NH4(2)); % distribute benthic NH4 among primary producers; rescaled to allow NH4 oxidation to NO3

% step 8g: append metabolism (aka: NH4, excretion, nutrient recycling) into BigMatrix
BigMatrix(looky_PelagicNH4, (num_NitrogenNutrients+1):(num_NitrogenNutrients+clms_BioBudg_pred)) = BioenergeticBudget_metabolism .* ExcretionFate(1, :); % metabolism to pelagic pool
BigMatrix(looky_BenthicNH4, (num_NitrogenNutrients+1):(num_NitrogenNutrients+clms_BioBudg_pred)) = BioenergeticBudget_metabolism .* ExcretionFate(2, :); % metabolism to benthic pool

% step 8h: append IMPLICIT bacterial oxidation of terminal pelagic detritus & terminal benthic detritus into BigMatrix
% NOTE: set detritus oxidation to 0 in "ECOTRAN recycling" excel tab if these processes included as EXPLICIT boxes
% NOTE: there is no implicit DIRECT bacterial processing of non-terminal detritus groups like offal (offal IS used by bacteria AS it enters terminal benthic detritus pool)
BigMatrix(looky_PelagicNH4, looky_PelagicDetritus)              = PelagicBacterialReduction; % fraction of terminal pelagic detritus oxidized to pelagic NH4
BigMatrix(looky_BenthicNH4, looky_BenthicDetritus)              = BenthicBacterialReduction; % fraction of terminal benthic detritus oxidized to benthic NH4
BigMatrix((num_NitrogenNutrients+1):end, looky_PelagicDetritus) = BigMatrix((num_NitrogenNutrients+1):end, looky_PelagicDetritus) * (1 - PelagicBacterialReduction); % reduce predation on PELAGIC detritus by groups other than bacteria
BigMatrix((num_NitrogenNutrients+1):end, looky_BenthicDetritus) = BigMatrix((num_NitrogenNutrients+1):end, looky_BenthicDetritus) * (1 - BenthicBacterialReduction); % reduce predation on BENTHIC detritus by groups other than bacteria

% QQQ fix these [BioenergeticBudget_production; BioenergeticBudget_feces; BioenergeticBudget_metabolism]



% % QQQ disable 10-17-2013
% % step 8j: renormalize non-fishery consumer columns to sum to 1
% % NOTE: this removes BA & EM production from BigMatrix;
% %       BA & EM terms are handled and accessed via the BioenergeticBudget & ProductionBudget variables
% looky_NonFishery                = 1:num_ECOTRAN_groups;
% looky_NonFishery(looky_Fishery) = [];
% sum_BigMatrix = sum(BigMatrix);
% for normal_loop = 1:num_ECOTRAN_groups
%     BigMatrix(normal_loop, looky_NonFishery) = BigMatrix(normal_loop, looky_NonFishery) ./ sum_BigMatrix(looky_NonFishery);
% end
% BigMatrix(isnan(BigMatrix)) = 0; % catch any div/0 errors (this should be rare)





% *************************************************************************
% STEP 9: put together Budget terms----------------------------------------
BioenergeticBudget(1:3, :)                  = [BioenergeticBudget_production; BioenergeticBudget_feces; BioenergeticBudget_metabolism]; % each clm should sum to 1
BioenergeticBudget_SumPredation             = sum(BigMatrix, 1) - sum(BigMatrix([looky_Nutrients; looky_Eggs; looky_Detritus], :), 1); % total BioenergeticBudget going to consumers
BioenergeticBudget_eggs                     = sum(BioenergeticBudget_OtherMortDetail(looky_EggsInDetritus, :), 1); % collapse rows of egg types for each column; (QQQ in future, add way to force this value early in the code)
BioenergeticBudget_OtherMortDetail          = BioenergeticBudget_OtherMortDetail(looky_DetrInDetritus, :); % remove eggs from this budget
BioenergeticBudget_OtherMortality           = sum(BioenergeticBudget_OtherMortDetail, 1); % total "other mortality" in BioenergeticBudget
BioenergeticBudget_FecesDetail              = BioenergeticBudget_FecesDetail(looky_DetrInDetritus, :); % remove eggs from this budget
BioenergeticBudget_ProductionDetail(1:5, :) = [BioenergeticBudget_SumPredation(1, (num_NitrogenNutrients+1):end); BioenergeticBudget_eggs; BioenergeticBudget_OtherMortality; BioenergeticBudget_BA; BioenergeticBudget_EM];
BioenergeticBudget_MetabolismDetail(1:2, :) = [(BioenergeticBudget_metabolism .* ExcretionFate(1, :)); (BioenergeticBudget_metabolism .* ExcretionFate(2, :))];

ProductionBudget_eggs                       = sum(ProductionBudget_OtherMortDetail(looky_EggsInDetritus, :), 1);
ProductionBudget_OtherMortDetail            = ProductionBudget_OtherMortDetail(looky_DetrInDetritus, :); % remove eggs from this budget
ProductionBudget_OtherMortality             = ProductionBudget_OtherMortality - ProductionBudget_eggs; % subtract eggs because eggs now accounted for separately
ProductionBudget(1:5, :)                    = [ProductionBudget_predation; ProductionBudget_eggs; ProductionBudget_OtherMortality; ProductionBudget_BA; ProductionBudget_EM];

GroupType_detritus                          = GroupType_EggsAndDetritus(looky_DetrInDetritus); % GroupType for the budget OtherMortDetail and FecesDetail
AggLabel_detritus                           = AggLabel_EggsAndDetritus(looky_DetrInDetritus); % AggLabels for the budget OtherMortDetail and FecesDetail

% step 9b: append nutrients to BioenergeticBudget & ProductionBudget terms
BioenergeticBudget                                              = [zeros(3, num_NitrogenNutrients) BioenergeticBudget]; % add columns for nutrients; nutrients MUST be in first columns
BioenergeticBudget(1, 1:num_NitrogenNutrients)                  = 1; % all nutrient input goes to production
BioenergeticBudget(3, looky_PelagicDetritus)                    = PelagicBacterialReduction; % fraction of terminal pelagic detritus oxidized to pelagic NH4
BioenergeticBudget(3, looky_BenthicDetritus)                    = BenthicBacterialReduction; % fraction of terminal pelagic detritus oxidized to pelagic NH4
BioenergeticBudget(1, looky_PelagicDetritus)                    = BioenergeticBudget(1, looky_PelagicDetritus) - PelagicBacterialReduction; % subtract bacterial metabolism from terminal detritus production in BioenergeticBudget
BioenergeticBudget(1, looky_BenthicDetritus)                    = BioenergeticBudget(1, looky_BenthicDetritus) - BenthicBacterialReduction; % fraction of terminal pelagic detritus oxidized to pelagic NH4
BioenergeticBudget_ProductionDetail                             = [zeros(5, num_NitrogenNutrients) BioenergeticBudget_ProductionDetail]; % add columns for nutrients; nutrients MUST be in first columns
BioenergeticBudget_ProductionDetail(1, 1:num_NitrogenNutrients) = 1; % all nutrient input goes to predation (= consumption by phytoplankton)
BioenergeticBudget_OtherMortDetail                              = [zeros(num_detritus, num_NitrogenNutrients) BioenergeticBudget_OtherMortDetail]; % add columns for nutrients; no nutrient flow into detritus groups
BioenergeticBudget_FecesDetail                                  = [zeros(num_detritus, num_NitrogenNutrients) BioenergeticBudget_FecesDetail]; % add columns for nutrients; no nutrient flow into feces groups
BioenergeticBudget_MetabolismDetail                             = [zeros(2, num_NitrogenNutrients) BioenergeticBudget_MetabolismDetail]; % add columns for nutrients; nutrient metabolism = 0 
ProductionBudget                                                = [zeros(5, num_NitrogenNutrients) ProductionBudget]; % add columns for nutrients; nutrients MUST be in first columns
ProductionBudget(1, 1:num_NitrogenNutrients)                    = 1; % all nutrient input goes to predation; nutrients MUST be in first columns
ProductionBudget_OtherMortDetail                                = [zeros(num_detritus, num_NitrogenNutrients) ProductionBudget_OtherMortDetail]; % add columns for nutrients; no nutrient flow into detritus groups

% step 9c: corrections for terminal detritus groups
% correct BioenergeticBudget_SumPredation for terminal detritus (substitute values that have not been altered to include implied bacterial metabolism as in BigMatrix; use ProductionBudget_predation)
BioenergeticBudget_ProductionDetail(1, [looky_PelagicDetritus looky_BenthicDetritus]) = ProductionBudget(1, [looky_PelagicDetritus looky_BenthicDetritus]) .* BioenergeticBudget(1, [looky_PelagicDetritus looky_BenthicDetritus]); % predation
BioenergeticBudget_ProductionDetail(3, [looky_PelagicDetritus looky_BenthicDetritus]) = ProductionBudget(3, [looky_PelagicDetritus looky_BenthicDetritus]) .* BioenergeticBudget(1, [looky_PelagicDetritus looky_BenthicDetritus]); % other mortality
BioenergeticBudget_ProductionDetail(5, [looky_PelagicDetritus looky_BenthicDetritus]) = ProductionBudget(5, [looky_PelagicDetritus looky_BenthicDetritus]) .* BioenergeticBudget(1, [looky_PelagicDetritus looky_BenthicDetritus]); % other mortality

% QQQ error is here
% BioenergeticBudget_ProductionDetail row 3 (other mortality) needs scaling


% step 9d: append nutrient rows to EwE parameters (nutrients MUST be in first rows)
EwE_Biomass             = [(zeros(num_NitrogenNutrients, 1) .* NaN); EwE_Biomass]; % NaN value is a place-holder
EwE_PB                  = [(zeros(num_NitrogenNutrients, 1) .* NaN); EwE_PB]; % NaN value is a place-holder
EwE_QB                  = [zeros(num_NitrogenNutrients, 1);          EwE_QB];
EwE_PQ                  = [ones(num_NitrogenNutrients, 1);           EwE_PQ];
EwE_AE                  = [ones(num_NitrogenNutrients, 1);           EwE_AE];
EwE_BA                  = [zeros(num_NitrogenNutrients, 1);          EwE_BA];
EwE_EM                  = [zeros(num_NitrogenNutrients, 1);          EwE_EM];
DetritusFate_feces      = [zeros(2, num_NitrogenNutrients)           DetritusFate_feces];
DetritusFate_senescence = [zeros(2, num_NitrogenNutrients)           DetritusFate_senescence];
ExcretionFate           = [zeros(2, num_NitrogenNutrients)           ExcretionFate];

% step 9e: append nutrient and fisheries rows to EwE_Landings, EwE_Discards, and EwE_TotalFishery
EwE_Landings     = [zeros(num_NitrogenNutrients, num_fisheries); EwE_Landings;     zeros(num_fisheries, num_fisheries)];
EwE_Discards     = [zeros(num_NitrogenNutrients, num_fisheries); EwE_Discards;     zeros(num_fisheries, num_fisheries)];
% EwE_TotalFishery = [zeros(num_NitrogenNutrients, num_fisheries); EwE_TotalFishery'; zeros(num_fisheries, num_fisheries)]; % QQQ transpose errro --- (NOTE: transpose only to EwE_TotalFishery)
EwE_TotalFishery = [zeros(num_NitrogenNutrients, num_fisheries); EwE_TotalFishery; zeros(num_fisheries, num_fisheries)]; %

% step 9f: transpose and append nutrient clms to EcotrophicEfficiency and TransferEfficiency
EcotrophicEfficiency_predation = [ones(1, num_NitrogenNutrients) EcotrophicEfficiency_predation']; % all production is assumed to be used by primary producers; NOTE: transpose
EcotrophicEfficiency_BA        = [zeros(1, num_NitrogenNutrients) EcotrophicEfficiency_BA']; % NOTE: transpose
EcotrophicEfficiency_EM        = [zeros(1, num_NitrogenNutrients) EcotrophicEfficiency_EM']; % 0 value is a place-holder; NOTE: transpose
EcotrophicEfficiency           = [ones(1, num_NitrogenNutrients) EcotrophicEfficiency']; % all production is assumed to be used by primary producers; NOTE: transpose
TransferEfficiency             = [ones(1, num_NitrogenNutrients) TransferEfficiency']; % all production is assumed to be used by primary producers; NOTE: transpose





% *************************************************************************
% STEP 10: get egg fate----------------------------------------------------
% make an egg_fate to allow distribution of egg metabolism between [] and n egg rows
[E2E_rows, E2E_clms] = size(BigMatrix);
EggFate              = zeros(num_eggs, E2E_clms); % initialize
if num_eggs > 0
    
%     EggFate                 = ones(egg_dim, E2E_clms);
    EggFate                 = BigMatrix(looky_Eggs, 1:E2E_clms);
    sum_eggs                = sum(EggFate, 1);
    EggFate                 = EggFate ./ repmat(sum_eggs, [num_eggs, 1]); % renormalize each clm to 1
    EggFate(isnan(EggFate)) = 0; % filter div/0 errors
end





% *************************************************************************
% STEP 11: package results for export--------------------------------------
% step 11a: THE MAIN ECOTRAN MODEL (does NOT include BA & EM rows)
SINGLE_ECO.BigMatrix                           = BigMatrix;

% step 11b: GroupType & AggLabel (rows match BigMatrix with nutrients, but also have BA & EM appended to bottom)
SINGLE_ECO.GroupType                           = GroupType;
SINGLE_ECO.GroupType_detritus                  = GroupType_detritus;
SINGLE_ECO.AggLabel                            = AggLabel;
SINGLE_ECO.AggLabel_detritus                   = AggLabel_detritus;

% step 11c: parameters (no rows for nutrients, EM, BA)
SINGLE_ECO.EwE_Biomass                         = EwE_Biomass;
SINGLE_ECO.EwE_PB                              = EwE_PB;
SINGLE_ECO.EwE_QB                              = EwE_QB;
SINGLE_ECO.EwE_PQ                              = EwE_PQ;
SINGLE_ECO.EwE_AE                              = EwE_AE;
SINGLE_ECO.EwE_BA                              = EwE_BA;
SINGLE_ECO.EwE_EM                              = EwE_EM;
SINGLE_ECO.DetritusFate_feces                  = DetritusFate_feces;
SINGLE_ECO.DetritusFate_senescence             = DetritusFate_senescence;
SINGLE_ECO.ExcretionFate                       = ExcretionFate;
SINGLE_ECO.EggFate                             = EggFate;
SINGLE_ECO.EwE_Landings                        = EwE_Landings;
SINGLE_ECO.EwE_Discards                        = EwE_Discards;
SINGLE_ECO.EwE_TotalFishery                    = EwE_Landings + EwE_Discards; % note that this writes over the old variable and has transposed dimensions from original

% step 11d: BioenergeticBudget & ProductionBudget
SINGLE_ECO.BioenergeticBudget                  = BioenergeticBudget;                  % row 1 = BioenergeticBudget_production
                                                                                      % row 2 = BioenergeticBudget_feces
                                                                                      % row 3 = BioenergeticBudget_metabolism
                                                                                      
SINGLE_ECO.BioenergeticBudget_ProductionDetail = BioenergeticBudget_ProductionDetail; % row 1 = BioenergeticBudget_SumPredation (total consumption of each group p going to all its consumers)
                                                                                      % row 2 = BioenergeticBudget_eggs (total consumption of each group p going to eggs, gametes, or live births)
                                                                                      % row 3 = BioenergeticBudget_OtherMortality (total consumption of each group p going to 
                                                                                      % row 4 = BioenergeticBudget_BA (total consumption of each group p going to biomass accumulation)
                                                                                      % row 5 = BioenergeticBudget_EM (total consumption of each group p going to emigration)

SINGLE_ECO.BioenergeticBudget_OtherMortDetail  = BioenergeticBudget_OtherMortDetail;  % fraction of consumption of each group p going to each detritus pool as "OtherMortality"; 1 row for each detritus type in original EwE model as BEFORE combining into terminal detritus pools (no eggs)
SINGLE_ECO.BioenergeticBudget_FecesDetail      = BioenergeticBudget_FecesDetail;      % fraction of consumption of each group p going to each detritus pool as feces; 1 row for each detritus type in original EwE model as BEFORE combining into terminal detritus pools (no eggs)

SINGLE_ECO.ProductionBudget                    = ProductionBudget;                    % row 1 = ProductionBudget_predation (total production of each group p going to the sum of all predation pressure on each group p)
                                                                                      % row 2 = ProductionBudget_eggs (total production of each group p going to eggs, gametes, or live births)
                                                                                      % row 3 = ProductionBudget_OtherMortality
                                                                                      % row 4 = ProductionBudget_BA
                                                                                      % row 5 = ProductionBudget_EM
                                                    
SINGLE_ECO.ProductionBudget_OtherMortDetail   = ProductionBudget_OtherMortDetail;     % fraction of production of each group p going to each detritus pool; 1 row for each detritus type in original EwE model as BEFORE combining into terminal detritus pools (no eggs)

% step 11e: Ecotrophic Efficiencies and TransferEfficiencies
SINGLE_ECO.EcotrophicEfficiency_predation     = EcotrophicEfficiency_predation;       % (= ProductionBudget_predation';
SINGLE_ECO.EcotrophicEfficiency_BA            = EcotrophicEfficiency_BA;              % (= ProductionBudget_BA')
SINGLE_ECO.EcotrophicEfficiency_EM            = EcotrophicEfficiency_EM;              % (= ProductionBudget_EM')
SINGLE_ECO.EcotrophicEfficiency               = EcotrophicEfficiency;                 % (= EcotrophicEfficiency_predation + EcotrophicEfficiency_EM + EcotrophicEfficiency_BA)
SINGLE_ECO.TransferEfficiency                 = TransferEfficiency;                   % (= EcotrophicEfficiency .* EwE_PQ) ((M2_p + EM_p + BA_p) / Q_p) = fraction of consumption by each group, c, passed upwards in food web via predation, BA, and EM





% end of m-file************************************************************